( cd usr/doc/gutenprint-5.0.0 ; rm -rf doc )
( cd usr/doc/gutenprint-5.0.0 ; ln -sf /usr/share/gutenprint/doc doc )
( cd usr/doc/gutenprint-5.0.0 ; rm -rf samples )
( cd usr/doc/gutenprint-5.0.0 ; ln -sf /usr/share/gutenprint/samples samples )
( cd usr/lib ; rm -rf libgutenprint.so.2 )
( cd usr/lib ; ln -sf libgutenprint.so.2.0.0 libgutenprint.so.2 )
( cd usr/lib ; rm -rf libgutenprintui.so )
( cd usr/lib ; ln -sf libgutenprintui.so.1.0.0 libgutenprintui.so )
( cd usr/lib ; rm -rf libgutenprintui2.so.1 )
( cd usr/lib ; ln -sf libgutenprintui2.so.1.0.0 libgutenprintui2.so.1 )
( cd usr/lib ; rm -rf libgutenprintui.so.1 )
( cd usr/lib ; ln -sf libgutenprintui.so.1.0.0 libgutenprintui.so.1 )
( cd usr/lib ; rm -rf libgutenprintui2.so )
( cd usr/lib ; ln -sf libgutenprintui2.so.1.0.0 libgutenprintui2.so )
( cd usr/lib ; rm -rf libgutenprint.so )
( cd usr/lib ; ln -sf libgutenprint.so.2.0.0 libgutenprint.so )
